@@ -26,7 +26,7 @@ from ...exceptions import RipeAtlasToolsException
 from ...helpers.colours import colourise
 from ...helpers.validators import ArgumentType
 from ...renderers import Renderer
-from ...settings import conf
+from ...settings import conf, aliases, AliasesDB
 from ...streaming import Stream, CaptureLimitExceeded
 from ..base import Command as BaseCommand
 
@@ -123,6 +123,12 @@ class Command(BaseCommand):
                  "the URL at which you can later get information about the "
                  "measurement."
         )
+        self.parser.add_argument(
+            "--set-alias",
+            help="After creating the measurement, register an alias for it.",
+            type=ArgumentType.alias_is_valid,
+            metavar="ALIAS"
+        )
 
         self.parser.add_argument(
             "--interval",
@@ -204,6 +210,8 @@ class Command(BaseCommand):
                  "Example: --exclude-tag=system-ipv6-works"
         )
 
+        Renderer.add_arguments_for_available_renderers(self.parser)
+
     def run(self):
 
         self._account_for_selected_probes()
@@ -224,6 +232,11 @@ class Command(BaseCommand):
             "it can be found here:\n\n  {0}".format(url)
         )
 
+        if self.arguments.set_alias:
+            alias = self.arguments.set_alias
+            aliases["measurement"][alias] = pk
+            AliasesDB.write(aliases)
+
         if not self.arguments.no_report:
             self.stream(pk, url)
 
@@ -263,7 +276,7 @@ class Command(BaseCommand):
         self.ok("Connecting to stream...")
         try:
             Stream(capture_limit=self.arguments.probes, timeout=300).stream(
-                self.arguments.renderer, self._type, pk)
+                self.arguments.renderer, self.arguments, self._type, pk)
         except (KeyboardInterrupt, CaptureLimitExceeded):
             pass  # User said stop, so we fall through to the finally block.
         finally:
