@@ -20,9 +20,8 @@ import unittest
 
 from random import randint
 
-# Python 3.4+ comes with mock in unittest
 try:
-    from unittest import mock
+    from unittest import mock  # Python 3.4+
 except ImportError:
     import mock
 
@@ -36,7 +35,7 @@ from ripe.atlas.tools.commands.measure import (
     NtpMeasureCommand,
 )
 from ripe.atlas.tools.exceptions import RipeAtlasToolsException
-from ripe.atlas.tools.settings import Configuration
+from ripe.atlas.tools.settings import Configuration, AliasesDB
 
 from ..base import capture_sys_output
 
@@ -736,6 +735,18 @@ class TestMeasureCommand(unittest.TestCase):
 
     def test_add_arguments(self):
 
+        with capture_sys_output() as (stdout, stderr):
+            with self.assertRaises(SystemExit):
+                PingMeasureCommand().init_args([
+                    "ping",
+                    "--set-alias", "\\invalid"
+                ])
+            self.assertEqual(
+                stderr.getvalue().split("\n")[-2],
+                'ripe-atlas measure: error: argument --set-alias: '
+                '"\\invalid" does not appear to be a valid alias.'
+            )
+
         with capture_sys_output() as (stdout, stderr):
             with self.assertRaises(SystemExit):
                 PingMeasureCommand().init_args([
@@ -939,3 +950,33 @@ class TestMeasureCommand(unittest.TestCase):
         with capture_sys_output() as (stdout, stderr):
             with self.assertRaises(RipeAtlasToolsException):
                 cmd._account_for_selected_probes(),
+
+    def test_set_alias(self):
+        path_aliases = "ripe.atlas.tools.commands.measure.base.aliases"
+        new_aliases = copy.deepcopy(AliasesDB.DEFAULT)
+
+        with mock.patch(path_aliases, new_aliases):
+            path_AliasesDB = "ripe.atlas.tools.commands.measure.base.AliasesDB"
+            with mock.patch(path_AliasesDB, autospec=True) as new_AliasesDB:
+                new_AliasesDB.write.return_value = True
+
+                path_create = "ripe.atlas.tools.commands.measure.base.Command.create"
+                with mock.patch(path_create) as mock_create:
+                    mock_create.return_value = (
+                        True,
+                        {"measurements": [1234]}
+                    )
+                    cmd = PingMeasureCommand()
+                    cmd.init_args([
+                        "ping",
+                        "--target",
+                        "www.ripe.net",
+                        "--no-report",
+                        "--set-alias",
+                        "PING_RIPE"
+                    ])
+                    cmd.run()
+                    self.assertEqual(
+                        new_aliases["measurement"]["PING_RIPE"],
+                        1234
+                    )
