@@ -13,10 +13,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import mock
 import unittest
 import requests
 
+try:
+    from unittest import mock  # Python 3.4+
+except ImportError:
+    import mock
+
 from ripe.atlas.tools.commands.probe_search import Command
 from ripe.atlas.tools.exceptions import RipeAtlasToolsException
 from ripe.atlas.cousteau import Probe
