@@ -15,18 +15,24 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import copy
 import json
-import mock
 import os
 import sys
 import tempfile
 import unittest
 
+try:
+    from unittest import mock  # Python 3.4+
+except ImportError:
+    import mock
+
 from ripe.atlas.cousteau import Probe
 
 from ripe.atlas.tools.commands.report import Command
 from ripe.atlas.tools.exceptions import RipeAtlasToolsException
 from ripe.atlas.tools.renderers import Renderer
+from ripe.atlas.tools.settings import AliasesDB
 from ripe.atlas.tools.version import __version__
 from ..base import capture_sys_output, StringIO
 
@@ -56,7 +62,6 @@ class TestReportCommand(unittest.TestCase):
         "20 bytes from probe #945   92.111.237.94   to hsi.cablecom.ch (62.2.16.24): ttl=56 times:61.665,  23.833,  23.269, \n"
     )
 
-
     def setUp(self):
         self.cmd = Command()
 
@@ -107,6 +112,30 @@ class TestReportCommand(unittest.TestCase):
                     cmd.init_args(["--renderer", choice, "1"])
                     cmd.run()
 
+    def test_arg_renderer_traceroute_aspath_with_valid_radius_arg(self):
+        """User passed arg --traceroute-aspath-radius to traceroute_aspath renderer"""
+        # Mock AtlasRequest to fail run fast and test args validity.
+        path = 'ripe.atlas.cousteau.AtlasRequest.get'
+        with mock.patch(path) as mock_get:
+            mock_get.return_value = False, {}
+            with self.assertRaises(RipeAtlasToolsException):
+                cmd = Command()
+                cmd.init_args(["--renderer", "traceroute_aspath",
+                               "--traceroute-aspath-radius", "3",
+                               "1"])
+                cmd.run()
+
+    def test_arg_renderer_traceroute_aspath_with_invalid_radius_arg(self):
+        """User passed arg --traceroute-aspath-radius to traceroute_aspath renderer with invalid value"""
+        # Mock AtlasRequest to fail run fast and test args validity.
+        with capture_sys_output():
+            with self.assertRaises(SystemExit):
+                cmd = Command()
+                cmd.init_args(["--renderer", "traceroute_aspath",
+                               "--traceroute-aspath-radius", "blaaaaa",
+                               "1"])
+                cmd.run()
+
     def test_arg_aggregate_with_valid_choice(self):
         """User passed arg aggregate with valid type."""
         # Mock AtlasRequest to fail run fast and test args validity.
@@ -164,10 +193,30 @@ class TestReportCommand(unittest.TestCase):
 
     def test_arg_no_valid_msm_id(self):
         """User passed non valid type of measurement id."""
-        with capture_sys_output():
+        with capture_sys_output() as (stdout, stderr):
             with self.assertRaises(SystemExit):
                 self.cmd.init_args(["blaaa"])
                 self.cmd.run()
+            err = stderr.getvalue().split("\n")[-2]
+        self.assertEqual(
+            err,
+            'ripe-atlas report: error: argument measurement_id: "blaaa" '
+            'does not appear to be an existent measurement alias.'
+        )
+
+    def test_arg_valid_msm_alias(self):
+        """User passed a valid measurement alias."""
+        path_aliases = "ripe.atlas.tools.helpers.validators.aliases"
+        new_aliases = copy.deepcopy(AliasesDB.DEFAULT)
+        new_aliases['measurement']['UNITTEST_ALIAS'] = 1234
+        with mock.patch(path_aliases, new_aliases):
+            path_get = 'ripe.atlas.tools.commands.report.Command._get_results_from_api'
+            with mock.patch(path_get) as mock_get:
+                mock_get.side_effect = RipeAtlasToolsException
+                with self.assertRaises(RipeAtlasToolsException):
+                    self.cmd.init_args(["UNITTEST_ALIAS"])
+                    self.cmd.run()
+                mock_get.assert_called_once_with(1234)
 
     def test_measurement_failure(self):
         """Testcase where given measurement id doesn't exist."""
@@ -347,5 +396,5 @@ class TestReportCommand(unittest.TestCase):
         for in_string, out_string in tests.items():
             path = "ripe.atlas.tools.commands.base.open"
             content = mock.mock_open(read_data=in_string)
-            with mock.patch(path, content):
+            with mock.patch(path, content, create=True):
                 self.assertEqual(Command().user_agent, out_string)
